ete2.treeview._open_newick

Package ete2 :: Package treeview :: Module _open_newick |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.treeview._open_newick

     1  # #START_LICENSE###########################################################
     2  #
     3  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     4  # email: jhcepas@gmail.com
     5  #
     6  # This file is part of the Environment for Tree Exploration program (ETE).
     7  # http://ete.cgenomics.org
     8  #
     9  # ETE is free software: you can redistribute it and/or modify it
    10  # under the terms of the GNU General Public License as published by
    11  # the Free Software Foundation, either version 3 of the License, or
    12  # (at your option) any later version.
    13  #
    14  # ETE is distributed in the hope that it will be useful,
    15  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    16  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    17  # GNU General Public License for more details.
    18  #
    19  # You should have received a copy of the GNU General Public License
    20  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    21  #
    22  # #END_LICENSE#############################################################
    23  __VERSION__="ete2-2.0rev90"
    24  # -*- coding: utf-8 -*-
    25
    26  # Form implementation generated from reading ui file 'open_newick.ui'
    27  #
    28  # Created: Mon Sep 14 11:11:49 2009
    29  #      by: PyQt4 UI code generator 4.5.4
    30  #
    31  # WARNING! All changes made in this file will be lost!
    32
    33  try:
    34      from PyQt4 import QtCore, QtGui
    35  except ImportError:
    36      import QtCore, QtGui
    37
    38 -class Ui_OpenNewick(object):
    39 -    def setupUi(self, OpenNewick):
    40          OpenNewick.setObjectName("OpenNewick")
    41          OpenNewick.resize(569, 353)
    42          self.comboBox = QtGui.QComboBox(OpenNewick)
    43          self.comboBox.setGeometry(QtCore.QRect(460, 300, 81, 23))
    44          self.comboBox.setObjectName("comboBox")
    45          self.widget = QtGui.QWidget(OpenNewick)
    46          self.widget.setGeometry(QtCore.QRect(30, 10, 371, 321))
    47          self.widget.setObjectName("widget")
    48
    49          self.retranslateUi(OpenNewick)
    50          QtCore.QMetaObject.connectSlotsByName(OpenNewick)
    51
    52 -    def retranslateUi(self, OpenNewick):
    53          OpenNewick.setWindowTitle(QtGui.QApplication.translate("OpenNewick", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
    54